==> torque-4.0-source-release.zip: torque-4.0/torque-runtime/src/test/java/org/apache/torque/TorqueRuntimeExceptionTest.java <==
package org.apache.torque;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import java.io.PrintWriter;
import java.io.StringWriter;

/**
 * Tests the class TorqueRuntimeException
 */
public class TorqueRuntimeExceptionTest extends BaseTestCase
{
    /**
     * Tests whether printstackTrace works.
     */
    public void testPrintStackTrace()
    {
        StringWriter stringWriter = new StringWriter();
        PrintWriter writer = new PrintWriter(stringWriter);
        try
        {
            throw new TorqueRuntimeException();
        }
        catch (TorqueRuntimeException e)
        {
            e.printStackTrace(writer);
            assertTrue(stringWriter.toString().startsWith(
                    "org.apache.torque.TorqueRuntimeException"));
            assertTrue(stringWriter.toString().indexOf(
                    "org.apache.torque.TorqueRuntimeExceptionTest.testPrintStackTrace")
                        > 0);
        }

    }
}

==> torque-7.0-source-release.zip: torque-7.0/torque-runtime/src/test/java/org/apache/torque/TorqueRuntimeExceptionTest.java <==
package org.apache.torque;

import static org.junit.jupiter.api.Assertions.assertTrue;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import java.io.PrintWriter;
import java.io.StringWriter;

import org.junit.jupiter.api.Test;


/**
 * Tests the class TorqueRuntimeException
 */
public class TorqueRuntimeExceptionTest
{
    /**
     * Tests whether printstackTrace works.
     */
	@Test
    public void testPrintStackTrace()
    {
        StringWriter stringWriter = new StringWriter();
        PrintWriter writer = new PrintWriter(stringWriter);
        try
        {
            throw new TorqueRuntimeException();
        }
        catch (TorqueRuntimeException e)
        {
            e.printStackTrace(writer);
            assertTrue(stringWriter.toString().startsWith(
                    "org.apache.torque.TorqueRuntimeException"));
            assertTrue(stringWriter.toString().indexOf(
                    "org.apache.torque.TorqueRuntimeExceptionTest.testPrintStackTrace")
                    > 0);
        }

    }
}
